pub enum Error {
Show 22 variants
Authentication,
Exhausted,
Unavailable,
UserCanceled,
InvalidActionId,
InvalidText,
AppCanceled,
SystemCanceled,
BiometryDisconnected,
NotPaired,
NotEnrolled,
NotInteractive,
CompanionNotAvailable,
InvalidDimensions,
PasscodeNotSet,
UserFallback,
UpdateRequired,
Timeout,
Busy,
DisabledByPolicy,
NotConfigured,
Unknown,
}Expand description
An error produced during authentication.
Variants
Authentication
The user failed to provide valid credentials.
Exhausted
Authentication failed because there were too many failed attempts.
The requested authentication method was unavailable.
UserCanceled
The user canceled authentication.
InvalidActionId
The provided action ID is not in the policy’s allowed list.
InvalidText
The prompt text is invalid for this platform — e.g. an empty
Text::apple reason or an empty AndroidText::title, which the
platform APIs reject.
AppCanceled
SystemCanceled
BiometryDisconnected
The device supports biometry only using a removable accessory, but the paired accessory isn’t connected.
This error can occur on:
NotPaired
The device supports biometry only using a removable accessory, but no accessory is paired.
This error can occur on:
NotEnrolled
NotInteractive
CompanionNotAvailable
An attempt to authenticate with an Apple companion device (e.g., Apple Watch) failed.
This error can occur on:
- Apple, formerly known as
WatchNotAvailable
InvalidDimensions
This error can occur on:
PasscodeNotSet
UserFallback
The user tapped the fallback button in the authentication dialog (e.g., “Use Password” instead), but you selected an authentication policy that does not support password fallback.
If you get this error, you either must handle the fallback yourself or enable the password option
in the policy builder, which will instruct the system to enable a password fallback option
in the authentication dialog.
This error can occur on:
UpdateRequired
Timeout
Busy
The biometric verifier device is performing an operation and is unavailable.
This error can occur on:
DisabledByPolicy
NotConfigured
Unknown
An unknown error occurred.