Error

Enum Error 

pub enum Error {
Show 22 variants Authentication, Exhausted, Unavailable, UserCanceled, InvalidActionId, InvalidText, AppCanceled, SystemCanceled, BiometryDisconnected, NotPaired, NotEnrolled, NotInteractive, CompanionNotAvailable, InvalidDimensions, PasscodeNotSet, UserFallback, UpdateRequired, Timeout, Busy, DisabledByPolicy, NotConfigured, Unknown,
}
An error produced during authentication.

Variants



Authentication

The user failed to provide valid credentials.



Exhausted

Authentication failed because there were too many failed attempts.



Unavailable

The requested authentication method was unavailable.



UserCanceled

The user canceled authentication.



InvalidActionId

The provided action ID is not in the policy’s allowed list.



InvalidText

The prompt text is invalid for this platform — e.g. an empty Text::apple reason or an empty AndroidText::title, which the platform APIs reject.



AppCanceled

The app canceled authentication.

This error can occur on:



SystemCanceled

The system canceled authentication.

This error can occur on:



BiometryDisconnected

The device supports biometry only using a removable accessory, but the paired accessory isn’t connected.

This error can occur on:



NotPaired

The device supports biometry only using a removable accessory, but no accessory is paired.

This error can occur on:



NotEnrolled

The user has no enrolled biometric identities.

This error can occur on:



NotInteractive

Displaying the required authentication user interface is forbidden.

This error can occur on:



CompanionNotAvailable

An attempt to authenticate with an Apple companion device (e.g., Apple Watch) failed.

This error can occur on:

  • Apple, formerly known as WatchNotAvailable


InvalidDimensions

This error can occur on:



PasscodeNotSet

A passcode isn’t set on the device.

This error can occur on:



UserFallback

The user tapped the fallback button in the authentication dialog (e.g., “Use Password” instead), but you selected an authentication policy that does not support password fallback.

If you get this error, you either must handle the fallback yourself or enable the password option in the policy builder, which will instruct the system to enable a password fallback option in the authentication dialog.

This error can occur on:



UpdateRequired



Timeout



Busy

The biometric verifier device is performing an operation and is unavailable.

This error can occur on:



DisabledByPolicy

Group policy has disabled the biometric verifier device.

This error can occur on:



NotConfigured

A biometric verifier device is not configured for this user.

This error can occur on:



Unknown

An unknown error occurred.